"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

exports.toTableColumns = toTableColumns;

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _reactBootstrapTable = require("react-bootstrap-table");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var DEFAULT_TABLE_CONF = {
  cellEdit: {
    mode: "click",
    blurToSave: true
  },
  options: {},
  selectRow: {
    mode: "checkbox"
  },
  deleteRow: true
};

function toEditable(fieldProp) {
  if (fieldProp.enum) {
    return {
      type: "select",
      options: { values: fieldProp.enum }
    };
  } else if (fieldProp.type === "boolean") {
    return {
      type: "checkbox"
    };
  } else if (fieldProp.type === "date-time") {
    return {
      type: "datetime"
    };
  } else if (fieldProp.type === "date") {
    return {
      type: "date"
    };
  } else if (fieldProp.type === "time") {
    return {
      type: "time"
    };
  }
  return true;
}

function toTableColumns(schema) {
  var tableCols = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var properties = schema.items.properties;


  var schemaCols = Object.keys(properties).map(function (dataField) {
    var title = properties[dataField].title;

    var editable = toEditable(properties[dataField]);
    return { dataField: dataField, displayName: title, editable: editable };
  });

  return schemaCols.map(function (sCol) {
    var tCol = tableCols.find(function (col) {
      return col.dataField === sCol.dataField;
    });
    return Object.assign(sCol, tCol);
  });
}

var TableField = function (_Component) {
  _inherits(TableField, _Component);

  function TableField() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, TableField);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = TableField.__proto__ || Object.getPrototypeOf(TableField)).call.apply(_ref, [this].concat(args))), _this), _this.handleCellSave = function (updRow) {
      var _this$props = _this.props,
          keyField = _this$props.uiSchema.table.keyField,
          formData = _this$props.formData;

      var targetKey = updRow[keyField];

      var updTable = formData.map(function (row) {
        return row[keyField] === targetKey ? updRow : row;
      });

      _this.props.onChange(updTable);
      return updTable;
    }, _this.handleRowsDelete = function (removedKeys) {
      var _this$props2 = _this.props,
          keyField = _this$props2.uiSchema.table.keyField,
          formData = _this$props2.formData;


      var filteredRows = formData.filter(function (row) {
        var rowKey = row[keyField];
        return !removedKeys.includes(rowKey);
      });
      _this.props.onChange(filteredRows);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(TableField, [{
    key: "render",
    value: function render() {
      var _props = this.props,
          schema = _props.schema,
          table = _props.uiSchema.table,
          formData = _props.formData;


      var tableConf = Object.assign({}, DEFAULT_TABLE_CONF, table, {
        data: formData
      });

      tableConf.cellEdit.afterSaveCell = this.handleCellSave;
      tableConf.options.afterDeleteRow = this.handleRowsDelete;

      var columns = toTableColumns(schema, table.tableCols);

      return _react2.default.createElement(
        _reactBootstrapTable.BootstrapTable,
        tableConf,
        columns.map(function (column, i) {
          return _react2.default.createElement(
            _reactBootstrapTable.TableHeaderColumn,
            _extends({ key: i }, column),
            column.displayName
          );
        })
      );
    }
  }]);

  return TableField;
}(_react.Component);

exports.default = TableField;